@@ -38,7 +38,7 @@ no warnings;
 
 our @EXPORT = qw( newretrieve newreport get_files );
 
-$VERSION = '0.095';
+$VERSION = '0.097';
 $ABSTRACT = 'Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results.';
 
 #########################################################################################
@@ -179,7 +179,9 @@ sub newretrieve
   my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } );
 
   my $shortresfile = $resfile;
-  $shortresfile =~ s/$thisto\/cfg\///; #say $tee "IN RETRIEVE: \$shortresfile: $shortresfile, \$resfile: $resfile, \$to: $to, \$thisto: $thisto, \$cleanto: $cleanto";
+  $shortresfile =~ s/$thisto// ; 
+  $shortresfile =~ s/\/cfg\///; 
+  #say $tee "IN RETRIEVE: \$shortresfile: $shortresfile, \$resfile: $resfile, \$to: $to, \$thisto: $thisto, \$cleanto: $cleanto";
 
   my $shortflfile = $flfile;
   $shortflfile =~ s/$thisto\/cfg\///; #say $tee "IN RETRIEVE: \$shortflfile: $shortflfile, \$flfile: $flfile";
@@ -200,7 +202,7 @@ sub newretrieve
 
         my $printthis =
 "cd $thisto/cfg
-res -file ../cfg/$shortresfile -mode script<<YYY
+res -file $resfile -mode script<<YYY
 
 3
 $retrdata[0]
@@ -250,7 +252,7 @@ YYY
         {
           my $printthis =
 "cd $thisto/cfg
-res -file ../cfg/$shortresfile -mode script<<ZZZ
+res -file $resfile -mode script<<ZZZ
 
 3
 $retrdata[0]
@@ -302,7 +304,7 @@ ZZZ
         {
           $printthis =
 "cd $thisto/cfg
-res -file ../cfg/$shortresfile -mode script<<TTT
+res -file $resfile -mode script<<TTT
 
 3
 $retrdata[0]
@@ -331,7 +333,7 @@ TTT
         {
           $printthis =
 "cd $thisto/cfg
-res -file ../cfg/$shortresfile -mode script<<TTT
+res -file $resfile -mode script<<TTT
 
 3
 $retrdata[0]
@@ -379,7 +381,7 @@ TTT
         {
           $printthis =
 "cd $thisto/cfg
-res -file ../cfg/$shortresfile -mode script<<TTT
+res -file $resfile -mode script<<TTT
 
 3
 $retrdata[0]
@@ -416,7 +418,7 @@ TTT
         elsif ( $themereport eq "radabs" )
         {
 "cd $thisto/cfg
-res -file ../cfg/$shortresfile -mode script<<TTT
+res -file $resfile -mode script<<TTT
 
 3
 $retrdata[0]
@@ -456,7 +458,7 @@ TTT
         {
           $printthis =
 "cd $thisto/cfg
-res -file ../cfg/$shortresfile -mode script<<TTT
+res -file $resfile -mode script<<TTT
 
 3
 $retrdata[0]
@@ -494,7 +496,7 @@ TTT
         {
           $printthis =
 "cd $thisto/cfg
-res -file ../cfg/$shortresfile -mode script<<TTT
+res -file $resfile -mode script<<TTT
 
 3
 $retrdata[0]
@@ -531,7 +533,7 @@ TTT
         elsif ( $themereport eq "restemp" )
         {
           $printthis =
-"res -file ../cfg/$shortresfile -mode script<<TTT
+"res -file $resfile -mode script<<TTT
 
 3
 $retrdata[0]
